← Back to team overview

widelands-dev team mailing list archive

[Merge] lp:~widelands-dev/widelands/bug-1341674 into lp:widelands

 

GunChleoc has proposed merging lp:~widelands-dev/widelands/bug-1341674 into lp:widelands.

Requested reviews:
  Widelands Developers (widelands-dev)
Related bugs:
  Bug #1341674 in widelands: "Consolidate TODO FIXME BUG to one style."
  https://bugs.launchpad.net/widelands/+bug/1341674

For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/bug-1341674/+merge/227693

While waiting for the compiler on another bug.... cleaned up TODO comments
-- 
https://code.launchpad.net/~widelands-dev/widelands/bug-1341674/+merge/227693
Your team Widelands Developers is requested to review the proposed merge of lp:~widelands-dev/widelands/bug-1341674 into lp:widelands.
=== modified file 'src/CMakeLists.txt'
--- src/CMakeLists.txt	2014-07-17 14:34:32 +0000
+++ src/CMakeLists.txt	2014-07-22 10:00:39 +0000
@@ -84,7 +84,7 @@
 add_subdirectory(ui_fsmenu)
 add_subdirectory(wui)
 
-# TODO: Ideally widelands_ball_of_mud shouldn't exist, everything should be in a
+# TODO(unknown): Ideally widelands_ball_of_mud shouldn't exist, everything should be in a
 # library.
 wl_library(widelands_ball_of_mud
   SRCS

=== modified file 'src/ai/defaultai.cc'
--- src/ai/defaultai.cc	2014-07-17 12:34:35 +0000
+++ src/ai/defaultai.cc	2014-07-22 10:00:39 +0000
@@ -564,8 +564,8 @@
 
 			if (upcast(PlayerImmovable const, player_immovable, &base_immovable))
 
-				//// TODO  Only continue; if this is an opposing site
-				//// TODO  allied sites should be counted for military influence
+				// TODO(unknown) Only continue; if this is an opposing site
+				// allied sites should be counted for military influence
 				if (player_immovable->owner().player_number() != pn) {
 					if (player_->is_hostile(player_immovable->owner()))
 						field.enemy_nearby_ = true;
@@ -620,11 +620,11 @@
 		const BaseImmovable& base_immovable = *immovables.at(i).object;
 
 		// testing if it is enemy-owned field
-		// TODO count such fields...
+		// TODO(unknown) count such fields...
 		if (upcast(PlayerImmovable const, player_immovable, &base_immovable))
 
-			// TODO  Only continue; if this is an opposing site
-			// TODO  allied sites should be counted for military influence
+			// TODO(unknown) Only continue; if this is an opposing site
+			// allied sites should be counted for military influence
 			if (player_immovable->owner().player_number() != pn) {
 				if (player_->is_hostile(player_immovable->owner()))
 					field.enemy_nearby_ = true;
@@ -1279,7 +1279,7 @@
 				// take care about borders and enemies
 				prio = recalc_with_border_range(*bf, prio);
 
-				// TODO:
+				// TODO(unknown):
 				// introduce check that there is no warehouse nearby to prevent to close placing
 
 			} else if (bo.type == BuildingObserver::TRAININGSITE) {
@@ -1595,8 +1595,8 @@
 				finish = connect_flag_to_another_economy(flag);
 
 			// try to improve the roads at this flag
-			//  TODO do this only on useful places - the attempt below
-			//  TODO  unfortunatey did not work as it should...
+			//  TODO(unknown) do this only on useful places - the attempt below
+			//  unfortunatey did not work as it should...
 			//  if the flag is full of wares or if it is not yet a fork.
 			if (!finish)  //&& (!flag.has_capacity() || flag.nr_of_roads() < 3))
 				finish = improve_transportation_ways(flag);
@@ -2554,8 +2554,8 @@
 
 // Checks that supply line exists for given building.
 // Recurcsively verify that all inputs_ have a producer.
-// TODO: this function leads to periodic freezes of ~1 second on big games on my system.
-// TODO: It needs profiling and optimization.
+// TODO(unknown): this function leads to periodic freezes of ~1 second on big games on my system.
+// TODO(unknown): It needs profiling and optimization.
 // NOTE: This is not needed anymore and it seems it is not missed neither
 bool DefaultAI::check_supply(const BuildingObserver& bo) {
 	size_t supplied = 0;

=== modified file 'src/economy/economy.cc'
--- src/economy/economy.cc	2014-07-03 19:26:30 +0000
+++ src/economy/economy.cc	2014-07-22 10:00:39 +0000
@@ -359,7 +359,7 @@
 	m_wares.add(id, count);
 	_start_request_timer();
 
-	// TODO: add to global player inventory?
+	// TODO(unknown): add to global player inventory?
 }
 void Economy::add_workers(Ware_Index const id, uint32_t const count)
 {
@@ -368,7 +368,7 @@
 	m_workers.add(id, count);
 	_start_request_timer();
 
-	// TODO: add to global player inventory?
+	// TODO(unknown): add to global player inventory?
 }
 
 /**
@@ -384,7 +384,7 @@
 
 	m_wares.remove(id, count);
 
-	// TODO: remove from global player inventory?
+	// TODO(unknown): remove from global player inventory?
 }
 
 /**
@@ -398,7 +398,7 @@
 
 	m_workers.remove(id, count);
 
-	// TODO: remove from global player inventory?
+	// TODO(unknown): remove from global player inventory?
 }
 
 /**

=== modified file 'src/economy/fleet.cc'
--- src/economy/fleet.cc	2014-07-14 22:18:03 +0000
+++ src/economy/fleet.cc	2014-07-22 10:00:39 +0000
@@ -358,7 +358,7 @@
 		}
 
 		if (pp.cost >= 0) {
-			// TODO: keep statistics on average transport time instead of using the arbitrary 2x factor
+			// TODO(unknown): keep statistics on average transport time instead of using the arbitrary 2x factor
 			RoutingNodeNeighbour neighb(&m_ports[otheridx]->base_flag(), 2 * pp.cost);
 			neighbours.push_back(neighb);
 		}

=== modified file 'src/economy/road.cc'
--- src/economy/road.cc	2014-07-14 14:40:42 +0000
+++ src/economy/road.cc	2014-07-22 10:00:39 +0000
@@ -55,7 +55,7 @@
 
 	/*
 	 * Initialize the worker slots for the road
-	 * TODO: make this configurable
+	 * TODO(unknown): make this configurable
 	 */
 	CarrierSlot slot;
 	m_carrier_slots.push_back(slot);
@@ -457,7 +457,7 @@
  * After the split, this road will span [start...new flag]. A new road will
  * be created to span [new flag...end]
 */
-// TODO SirVer: This need to take an Editor_Game_Base as well.
+// TODO(SirVer): This need to take an Editor_Game_Base as well.
 void Road::postsplit(Game & game, Flag & flag)
 {
 	Flag & oldend = *m_flags[FlagEnd];

=== modified file 'src/economy/test/test_routing.cc'
--- src/economy/test/test_routing.cc	2014-07-05 12:17:03 +0000
+++ src/economy/test/test_routing.cc	2014-07-22 10:00:39 +0000
@@ -17,8 +17,8 @@
  *
  */
 
-//  FIXME remove this pragma when boost-1.40 is required (when it has been
-//  FIXME accepted by distributions)
+//  TODO(unknown) remove this pragma when boost-1.40 is required (when it has been
+//  accepted by distributions)
 #pragma GCC diagnostic ignored "-Wold-style-cast"
 
 #include <exception>

=== modified file 'src/economy/wares_queue.cc'
--- src/editor/editorinteractive.cc	2014-07-14 10:45:44 +0000
+++ src/editor/editorinteractive.cc	2014-07-22 10:00:39 +0000
@@ -179,7 +179,7 @@
 
 	Widelands::Map & map = egbase().map();
 
-	// TODO: get rid of cleanup_for_load, it tends to be very messy
+	// TODO(unknown): get rid of cleanup_for_load, it tends to be very messy
 	// Instead, delete and re-create the egbase.
 	egbase().cleanup_for_load();
 	m_history.reset();
@@ -202,7 +202,7 @@
 
 	load_all_tribes(&egbase(), &loader_ui);
 
-	// Create the players. TODO SirVer this must be managed better
+	// Create the players. TODO(SirVer) this must be managed better
 	loader_ui.step(_("Creating players"));
 	iterate_player_numbers(p, map.get_nrplayers()) {
 		egbase().add_player(p, 0, map.get_scenario_player_tribe(p), map.get_scenario_player_name(p));
@@ -576,7 +576,7 @@
 void Editor_Interactive::run_editor(const std::string& filename, const std::string& script_to_run) {
 	Widelands::Editor_Game_Base editor(nullptr);
 	Editor_Interactive eia(editor);
-	editor.set_ibase(&eia); // TODO get rid of this
+	editor.set_ibase(&eia); // TODO(unknown) get rid of this
 	{
 		UI::ProgressWindow loader_ui("pics/editor.jpg");
 		std::vector<std::string> tipstext;

=== modified file 'src/editor/map_generator.cc'
--- src/editor/map_generator.cc	2014-07-16 08:23:42 +0000
+++ src/editor/map_generator.cc	2014-07-22 10:00:39 +0000
@@ -123,7 +123,7 @@
                                       uint32_t const* const random4,
                                       FCoords const fc) {
 	// We'll take the "D" terrain at first...
-	// TODO: Check how the editor handles this...
+	// TODO(unknown): Check how the editor handles this...
 
 	const World& world = egbase_.world();
 	Terrain_Index const tix = fc.field->get_terrains().d;
@@ -566,8 +566,8 @@
 		uint32_t const shelf_h   = map_gen_info_->getWaterShelfHeight();
 		uint32_t const shallow_h = map_gen_info_->getWaterShallowHeight();
 
-		//  TODO: The heights can not be lower than water-Shallow --
-		//  TODO: there will never be an ocean yet
+		//  TODO(unknown): The heights can not be lower than water-Shallow --
+		//  there will never be an ocean yet
 
 		if        (h1 <= ocean_h   && h2 <= ocean_h   && h3 <= ocean_h)   {
 			atp = MapGenAreaInfo::atWater;
@@ -847,7 +847,7 @@
 		}
 
 		if (coords.empty()) {
-			// TODO inform players via popup
+			// TODO(unknown) inform players via popup
 			log("WARNING: Could not find a suitable place for player %u\n", n);
 			// Let's hope that one is at least on dry ground.
 			coords2 = playerstart;
@@ -1159,12 +1159,12 @@
 	return hash;
 }
 
-// TODO: Also take mountain and water areas into bob generation
+// TODO(unknown): Also take mountain and water areas into bob generation
 // (we have ducks and chamois)
-// TODO: Define the "none"-bob to weigh other bobs lower within BobCategory...
-// TODO: MapGen: Bob generation, configurable in mapgenconf
-// TODO: MapGen: Resource generation, configurable in mapgenconf
-// TODO: MapGen: Check out sample map
-// TODO: MapGen: How to handle height profile in make_blah...
+// TODO(unknown): Define the "none"-bob to weigh other bobs lower within BobCategory...
+// TODO(unknown): MapGen: Bob generation, configurable in mapgenconf
+// TODO(unknown): MapGen: Resource generation, configurable in mapgenconf
+// TODO(unknown): MapGen: Check out sample map
+// TODO(unknown): MapGen: How to handle height profile in make_blah...
 
 }

=== modified file 'src/editor/ui_menus/categorized_item_selection_menu.h'
--- src/editor/ui_menus/categorized_item_selection_menu.h	2014-07-05 16:41:51 +0000
+++ src/editor/ui_menus/categorized_item_selection_menu.h	2014-07-22 10:00:39 +0000
@@ -141,9 +141,9 @@
 	if (protect_against_recursive_select_)
 		return;
 
-	//  FIXME This code is erroneous. It checks the current key state. What it
-	//  FIXME needs is the key state at the time the mouse was clicked. See the
-	//  FIXME usage comment for get_key_state.
+	//  TODO(unknown) This code is erroneous. It checks the current key state. What it
+	//  needs is the key state at the time the mouse was clicked. See the
+	//  usage comment for get_key_state.
 	const bool multiselect = get_key_state(SDLK_LCTRL) | get_key_state(SDLK_RCTRL);
 	if (not t and(not multiselect or tool_->get_nr_enabled() == 1))
 		checkboxes_[n]->set_state(true);

=== modified file 'src/editor/ui_menus/editor_main_menu.cc'
--- src/editor/ui_menus/editor_main_menu.cc	2014-07-14 10:45:44 +0000
+++ src/editor/ui_menus/editor_main_menu.cc	2014-07-22 10:00:39 +0000
@@ -28,7 +28,7 @@
 #include "editor/ui_menus/editor_main_menu_save_map.h"
 #include "ui_fsmenu/fileview.h"
 
-//TODO: these should be defined globally for the whole UI
+//TODO(unknown): these should be defined globally for the whole UI
 #define width 200
 #define height 20
 #define margin 15

=== modified file 'src/editor/ui_menus/editor_player_menu.cc'
--- src/editor/ui_menus/editor_player_menu.cc	2014-07-14 10:45:44 +0000
+++ src/editor/ui_menus/editor_player_menu.cc	2014-07-22 10:00:39 +0000
@@ -241,8 +241,8 @@
 	m_remove_last_player.set_enabled(1 < nr_players);
 
 	update();
-	// SirVer TODO: Take steps when the player is referenced someplace. Not
-	// SirVer TODO: currently possible in the editor though.
+	// TODO(SirVer): Take steps when the player is referenced someplace. Not
+	// TODO(SirVer): currently possible in the editor though.
 }
 
 /*
@@ -271,12 +271,12 @@
 //
 //                 map.set_nrplayers(nr_players);
 //                 map.set_scenario_player_name(nr_players, name);   //  ???
-//                 // SirVer TODO: next lines were commented without a clue
+//                 // TODO(SirVer): next lines were commented without a clue
 //                 // map.set_scenario_player_tribe(nr_players, tribe); //  ???
 //                 // menu.set_need_save(true);
 //                 m_add_player        .set_enabled(true);
 //                 m_remove_last_player.set_enabled(1 < nr_players);
-//                 // SirVer TODO: next lines were commented without a clue
+//                 // TODO(SirVer): next lines were commented without a clue
 //                 // if
 //                 //         (&menu.tools.current() == &menu.tools.set_starting_pos
 //                 //          and
@@ -290,7 +290,7 @@
 //                 // else
 //                         update();
 //         } else {
-//                 // SirVer, TODO: this error was commented without a clue
+//                 // TODO(SirVer): this error was commented without a clue
 //                 // UI::WLMessageBox mmb
 //                 //         (&menu,
 //                 //          _("Error!"),
@@ -399,7 +399,7 @@
 		// place a hq and reference the tribe
 		// so that this tribe can not be changed
 		egbase.add_player
-			(n, 0, // SirVer, TODO: initialization index makes no sense here
+			(n, 0, // TODO(SirVer): initialization index makes no sense here
 			 m_plr_set_tribes_buts[n - 1]->get_title(),
 			 m_plr_names[n - 1]->text());
 

=== modified file 'src/editor/ui_menus/editor_tool_place_bob_options_menu.cc'
--- src/editor/ui_menus/editor_tool_place_bob_options_menu.cc	2014-07-14 10:45:44 +0000
+++ src/editor/ui_menus/editor_tool_place_bob_options_menu.cc	2014-07-22 10:00:39 +0000
@@ -120,9 +120,9 @@
 	if (m_click_recursion_protect)
 		return;
 
-	//  FIXME This code is erroneous. It checks the current key state. What it
-	//  FIXME needs is the key state at the time the mouse was clicked. See the
-	//  FIXME usage comment for get_key_state.
+	//  TODO(unknown) This code is erroneous. It checks the current key state. What it
+	//  TODO(unknown) needs is the key state at the time the mouse was clicked. See the
+	//  TODO(unknown) usage comment for get_key_state.
 	const bool multiselect =
 		get_key_state(SDLK_LCTRL) | get_key_state(SDLK_RCTRL);
 	if (not t and (not multiselect or m_pit.get_nr_enabled() == 1)) {

=== modified file 'src/graphic/animation.cc'
--- src/graphic/animation.cc	2014-07-15 05:12:37 +0000
+++ src/graphic/animation.cc	2014-07-22 10:00:39 +0000
@@ -291,11 +291,11 @@
 	}
 
 	for (const std::string& filename : pc_mask_image_files_) {
-		// TODO Do not load playercolor mask as opengl texture or use it as
+		// TODO(unknown) Do not load playercolor mask as opengl texture or use it as
 		//     opengl texture.
 		const Image* pc_image = g_gr->images().get(filename);
 		if (frames_[0]->width() != pc_image->width() or frames_[0]->height() != pc_image->height()) {
-			// TODO: see bug #1324642
+			// TODO(unknown): see bug #1324642
 			throw wexception("playercolor mask has wrong size: (%u, %u), should "
 			                 "be (%u, %u) like the animation frame",
 			                 pc_image->width(),

=== modified file 'src/graphic/font_handler1.h'
--- src/graphic/font_handler1.h	2014-07-15 05:12:37 +0000
+++ src/graphic/font_handler1.h	2014-07-22 10:00:39 +0000
@@ -17,7 +17,7 @@
  *
  */
 
-// TODO: rename
+// TODO(unknown): rename
 #ifndef WL_GRAPHIC_FONT_HANDLER1_H
 #define WL_GRAPHIC_FONT_HANDLER1_H
 

=== modified file 'src/graphic/graphic.cc'
--- src/graphic/graphic.cc	2014-07-17 13:26:23 +0000
+++ src/graphic/graphic.cc	2014-07-22 10:00:39 +0000
@@ -336,7 +336,7 @@
 void Graphic::cleanup() {
 	m_maptextures.clear();
 	surface_cache_->flush();
-	// TODO: this should really not be needed, but currently is :(
+	// TODO(unknown): this should really not be needed, but currently is :(
 	if (UI::g_fh)
 		UI::g_fh->flush();
 
@@ -386,7 +386,7 @@
 void Graphic::toggle_fullscreen()
 {
 	log("Try SDL_WM_ToggleFullScreen...\n");
-	// TODO: implement proper fullscreening here. The way it can work is to
+	// TODO(unknown): implement proper fullscreening here. The way it can work is to
 	// recreate SurfaceCache but keeping ImageCache around. Then exiting and
 	// reinitalizing the SDL Video Mode should just work: all surface are
 	// recreated dynamically and correctly.

=== modified file 'src/graphic/render/gl_surface_screen.cc'
--- src/graphic/render/gl_surface_screen.cc	2013-08-01 08:49:59 +0000
+++ src/graphic/render/gl_surface_screen.cc	2014-07-22 10:00:39 +0000
@@ -59,7 +59,7 @@
 	m_pixels.reset(new uint8_t[m_w * m_h * 4]);
 
 	if (mode == Lock_Normal) {
-		// FIXME: terrain dither picture somehow leave the alpha
+		// TODO(unknown) terrain dither picture somehow leave the alpha
 		// channel with non-1 values, so it is cleared before
 		// accessing pixels.
 		glColorMask(false, false, false, true);

=== modified file 'src/graphic/render/minimaprenderer.cc'
--- src/graphic/render/minimaprenderer.cc	2014-07-17 13:26:23 +0000
+++ src/graphic/render/minimaprenderer.cc	2014-07-22 10:00:39 +0000
@@ -263,7 +263,7 @@
                                       const Point& viewpoint,
                                       MiniMapLayer layers) {
 	// First create a temporary SDL Surface to draw the minimap.
-	// TODO: Currently the minimap is redrawn every frame. That is not really
+	// TODO(unknown): Currently the minimap is redrawn every frame. That is not really
 	//       necesary. The created surface could be cached and only redrawn two
 	//       or three times per second
 	const Map& map = egbase.map();

=== modified file 'src/graphic/render/terrain_sdl.h'
--- src/graphic/render/terrain_sdl.h	2014-07-14 10:45:44 +0000
+++ src/graphic/render/terrain_sdl.h	2014-07-22 10:00:39 +0000
@@ -363,7 +363,7 @@
 	dty = (ITOFIX(end.ty) - ty) / (end.x - start.x + 1);
 	db  = (ITOFIX(end.b)  - b)  / (end.x - start.x + 1);
 
-	// TODO: seed this depending on field coordinates
+	// TODO(unknown): seed this depending on field coordinates
 	uint32_t rnd = 0;
 
 	const int32_t dstw = dst.width();
@@ -460,7 +460,7 @@
 	dty = (ITOFIX(end.ty) - ty) / (end.y - start.y + 1);
 	db  = (ITOFIX(end.b)  - b)  / (end.y - start.y + 1);
 
-	// TODO: seed this depending on field coordinates
+	// TODO(unknown): seed this depending on field coordinates
 	uint32_t rnd = 0;
 
 	const int32_t dstw = dst.width();
@@ -664,7 +664,7 @@
 
 	dst.unlock(Surface::Unlock_Update);
 
-	// FIXME: similar textures may not need dithering
+	// TODO(unknown) similar textures may not need dithering
 }
 
 #endif  // end of include guard: WL_GRAPHIC_RENDER_TERRAIN_SDL_H

=== modified file 'src/io/filesystem/disk_filesystem.cc'
--- src/io/filesystem/filesystem.h	2014-07-13 21:38:10 +0000
+++ src/io/filesystem/filesystem.h	2014-07-22 10:00:39 +0000
@@ -44,7 +44,7 @@
  */
 class FileSystem {
 public:
-	//  TODO This should be unnecessary. Make it so.
+	//  TODO(unknown) This should be unnecessary. Make it so.
 	enum Type {
 		DIR,
 		ZIP
@@ -65,7 +65,7 @@
 		(const std::string & fname, void const * data, int32_t length)
 		= 0;
 	virtual void EnsureDirectoryExists(const std::string & dirname) = 0;
-	//TODO: use this only from inside EnsureDirectoryExists()
+	//TODO(unknown): use this only from inside EnsureDirectoryExists()
 	virtual void MakeDirectory(const std::string & dirname) = 0;
 
 	/**

=== modified file 'src/io/filesystem/zip_filesystem.cc'
--- src/io/streamwrite.h	2014-07-14 19:48:07 +0000
+++ src/io/streamwrite.h	2014-07-22 10:00:39 +0000
@@ -56,7 +56,7 @@
 	 */
 	virtual void Flush();
 
-	//TODO: implement an overloaded method that accepts fmt as std::string
+	//TODO(unknown): implement an overloaded method that accepts fmt as std::string
 	void Printf(char const *, ...) __attribute__((format(printf, 2, 3)));
 
 	void   Signed8  (int8_t const x) {Data(&x, 1);}

=== modified file 'src/logic/battle.cc'
--- src/logic/battle.cc	2014-07-03 20:11:14 +0000
+++ src/logic/battle.cc	2014-07-22 10:00:39 +0000
@@ -138,8 +138,8 @@
 	return other_soldier;
 }
 
-//  FIXME Couldn't this code be simplified tremendously by doing all scheduling
-//  FIXME for one soldier and letting the other sleep until the battle is over?
+//  TODO(unknown) Couldn't this code be simplified tremendously by doing all scheduling
+//  for one soldier and letting the other sleep until the battle is over?
 //  Could be, but we need to be able change the animations of the soldiers
 //  easily without unneeded hacks, and this code is not so difficult, only it
 //  had some translations errors

=== modified file 'src/logic/building.cc'
--- src/logic/building.cc	2014-07-16 08:25:35 +0000
+++ src/logic/building.cc	2014-07-22 10:00:39 +0000
@@ -703,7 +703,7 @@
 */
 bool Building::fetch_from_flag(Game &)
 {
-	molog("TODO: Implement Building::fetch_from_flag\n");
+	molog("TODO(unknown): Implement Building::fetch_from_flag\n");
 
 	return false;
 }

=== modified file 'src/logic/carrier.cc'
--- src/logic/carrier.cc	2014-07-03 19:26:30 +0000
+++ src/logic/carrier.cc	2014-07-22 10:00:39 +0000
@@ -113,7 +113,7 @@
 		return;
 
 	// Be bored. There's nothing good on TV, either.
-	// TODO: idle animations
+	// TODO(unknown): idle animations
 	set_animation(game, descr().get_animation("idle"));
 	state.ivar1 = 1; //  we are available immediately after an idle phase
 	return skip_act(); //  wait until signal

=== modified file 'src/logic/carrier.h'
--- src/logic/carrier.h	2014-07-11 22:53:34 +0000
+++ src/logic/carrier.h	2014-07-22 10:00:39 +0000
@@ -42,7 +42,7 @@
 		{}
 
 		virtual Worker_Type get_worker_type() const override {return CARRIER;}
-		// class type needed for Lua stuffl TODO: redundant with get_worker_type()?
+		// class type needed for Lua stuff TODO(GunChleoc): redundant with get_worker_type()?
 		std::string type() const override {return "carrier";}
 
 	protected:

=== modified file 'src/logic/cmd_queue.cc'
--- src/logic/cmd_queue.cc	2014-07-03 19:26:30 +0000
+++ src/logic/cmd_queue.cc	2014-07-22 10:00:39 +0000
@@ -50,7 +50,7 @@
 /*
  * flushs all commands from the queue. Needed for
  * game loading (while in game)
- * FIXME ...but game loading while in game is not possible!
+ * TODO(unknown) ...but game loading while in game is not possible!
  * Note: Order of destruction of Items is not guaranteed
  */
 void Cmd_Queue::flush() {

=== modified file 'src/logic/constructionsite.cc'
--- src/logic/constructionsite.cc	2014-07-16 08:25:35 +0000
+++ src/logic/constructionsite.cc	2014-07-22 10:00:39 +0000
@@ -143,7 +143,7 @@
 		buildcost = &m_building->buildcost();
 	}
 
-	//  TODO figure out whether planing is necessary
+	//  TODO(unknown) figure out whether planing is necessary
 
 	//  initialize the wares queues
 	size_t const buildcost_size = buildcost->size();

=== modified file 'src/logic/editor_game_base.cc'
--- src/logic/editor_game_base.cc	2014-07-16 08:23:42 +0000
+++ src/logic/editor_game_base.cc	2014-07-22 10:00:39 +0000
@@ -70,7 +70,7 @@
 map_               (nullptr),
 lasttrackserial_   (0)
 {
-	if (not lua_) // TODO SirVer: this is sooo ugly, I can't say
+	if (not lua_) // TODO(SirVer): this is sooo ugly, I can't say
 		lua_.reset(new LuaEditorInterface(this));
 
 	g_sound_handler.egbase_ = this;
@@ -93,7 +93,7 @@
 
 void Editor_Game_Base::think()
 {
-	//TODO: Get rid of this; replace by a function that just advances gametime
+	//TODO(unknown): Get rid of this; replace by a function that just advances gametime
 	// by a given number of milliseconds
 }
 
@@ -260,7 +260,7 @@
 		}
 	}
 
-	// TODO: postload players? (maybe)
+	// TODO(unknown): postload players? (maybe)
 }
 
 
@@ -278,7 +278,7 @@
 		(*i.current)->load_graphics();
 	}
 
-	// TODO: load player graphics? (maybe)
+	// TODO(unknown): load player graphics? (maybe)
 }
 
 /**
@@ -589,7 +589,7 @@
 	//  Therefore the area must be enlarged before calling
 	//  cleanup_playerimmovables_area, so that those new border locations are
 	//  covered.
-	// SirVer, TODO: In the editor, no buildings should burn down when a military
+	// TODO(SirVer): In the editor, no buildings should burn down when a military
 	// building is removed. Check this again though
 	if (is_a(Game, this)) {
 		++player_area.radius;
@@ -635,7 +635,7 @@
 
 	fc.field->set_owned_by(new_owner);
 
-	// TODO: the player should do this when it gets the NoteFieldPossession.
+	// TODO(unknown): the player should do this when it gets the NoteFieldPossession.
 	// This means also sending a note when new_player = 0, i.e. the field is no
 	// longer owned.
 	inform_players_about_ownership(fc.field - &first_field, new_owner);
@@ -672,7 +672,7 @@
 
 /// Conquers the given area for that player; does the actual work.
 /// Additionally, it updates the visible area for that player.
-// TODO: this needs a more fine grained refactoring
+// TODO(unknown): this needs a more fine grained refactoring
 // for example scripts will want to (un)conquer area of non oval shape
 // or give area back to the neutral player (this is very important for the Lua
 // testsuite).

=== modified file 'src/logic/editor_game_base.h'
--- src/logic/editor_game_base.h	2014-07-16 08:23:42 +0000
+++ src/logic/editor_game_base.h	2014-07-22 10:00:39 +0000
@@ -247,7 +247,7 @@
 	// sends notifications about this.
 	void change_field_owner(const FCoords& fc, Player_Number new_owner);
 
-	// FIXME -- SDL returns time as uint32. Why do I have int32 ? Please comment or change this to
+	// TODO(unknown) -- SDL returns time as uint32. Why do I have int32 ? Please comment or change this to
 	// uint32.
 	int32_t gametime_;
 	Object_Manager objects_;

=== modified file 'src/logic/field.cc'
--- src/logic/field.cc	2013-07-26 20:19:36 +0000
+++ src/logic/field.cc	2014-07-22 10:00:39 +0000
@@ -50,7 +50,7 @@
 		b = -128;
 	else if (b >  127)
 		b =  127;
-	brightness = static_cast<int8_t>(b); //FIXME: ARGH !!
+	brightness = static_cast<int8_t>(b); //TODO(unknown): ARGH !!
 }
 
 }

=== modified file 'src/logic/game.cc'
--- src/logic/game.cc	2014-07-15 10:02:22 +0000
+++ src/logic/game.cc	2014-07-22 10:00:39 +0000
@@ -582,7 +582,7 @@
 		m_state = gs_running;
 		//handle network
 		while (m_state == gs_running) {
-			// TODO this should be improved.
+			// TODO(unknown) this should be improved.
 #ifndef _WIN32
 			if (usleep(100) == -1)
 				break;

=== modified file 'src/logic/map.cc'
--- src/logic/map.cc	2014-07-17 13:26:23 +0000
+++ src/logic/map.cc	2014-07-22 10:00:39 +0000
@@ -1636,7 +1636,7 @@
 			result.reset(new WL_Map_Loader(g_fs->MakeSubFileSystem(filename), this));
 		} catch (...) {
 			//  If this fails, it is an illegal file.
-			//  TODO: catchall hides real errors! Replace with more specific code
+			//  TODO(unknown): catchall hides real errors! Replace with more specific code
 		}
 	} else if (boost::algorithm::ends_with(lower_filename, S2MF_SUFFIX) ||
 	           boost::algorithm::ends_with(lower_filename, S2MF_SUFFIX2)) {

=== modified file 'src/logic/militarysite.cc'
--- src/logic/militarysite.cc	2014-07-17 12:08:01 +0000
+++ src/logic/militarysite.cc	2014-07-22 10:00:39 +0000
@@ -547,7 +547,7 @@
 */
 void MilitarySite::act(Game & game, uint32_t const data)
 {
-	// TODO: do all kinds of stuff, but if you do nothing, let
+	// TODO(unknown): do all kinds of stuff, but if you do nothing, let
 	// ProductionSite::act() handle all this. Also note, that some ProductionSite
 	// commands rely, that ProductionSite::act() is not called for a certain
 	// period (like cmdAnimation). This should be reworked.
@@ -565,7 +565,7 @@
 	// Therefore I must poll in some occasions. Let's do that rather infrequently,
 	// to keep the game lightweight.
 
-	//TODO: I would need two new callbacks, to get rid ot this polling.
+	//TODO(unknown): I would need two new callbacks, to get rid ot this polling.
 	if (timeofgame > m_next_swap_soldiers_time)
 		{
 			m_next_swap_soldiers_time = timeofgame + (m_soldier_upgrade_try ? 20000 : 100000);

=== modified file 'src/logic/partially_finished_building.cc'
--- src/logic/partially_finished_building.cc	2014-07-15 10:55:02 +0000
+++ src/logic/partially_finished_building.cc	2014-07-22 10:00:39 +0000
@@ -146,7 +146,7 @@
 0 = nothing built.
 ===============
 */
-// TODO: should take gametime or so
+// TODO(unknown): should take gametime or so
 uint32_t Partially_Finished_Building::get_built_per64k() const
 {
 	const uint32_t time = owner().egbase().get_gametime();

=== modified file 'src/logic/production_program.cc'
--- src/logic/production_program.cc	2014-07-16 08:23:42 +0000
+++ src/logic/production_program.cc	2014-07-22 10:00:39 +0000
@@ -303,7 +303,7 @@
 		condition = (boost::format(_("%s,")) % condition).str();
 	}
 	if (1 < group.second) {
-		// TODO this should be done with ngettext
+		// TODO(unknown) this should be done with ngettext
 		condition =
 			(boost::format(_("%1$s (%2$i)")) % condition % static_cast<unsigned int>(group.second)).str();
 	}
@@ -503,7 +503,7 @@
 				condition_string += i.front()->description(ps.owner().tribe());
 				if (i.advance().empty())
 					break;
-				// TODO  Would prefer "%1$s and %2$s" but getting segfaults, so leaving this for now
+				// TODO(unknown)  Would prefer "%1$s and %2$s" but getting segfaults, so leaving this for now
 				/** TRANSLATORS: 'Failed/Completed/Skipped %s because: %s {and %s}' */
 				condition_string = (boost::format(_("%s and ")) % condition_string).str();
 			}
@@ -520,7 +520,7 @@
 				condition_string += i.front()->description(ps.owner().tribe());
 				if (i.advance().empty())
 					break;
-				// TODO  Would prefer '%1$s or %2$s' but getting segfaults, so leaving this for now
+				// TODO(unknown)  Would prefer '%1$s or %2$s' but getting segfaults, so leaving this for now
 				/** TRANSLATORS: 'Failed/Completed/Skipped %s because not: %s {or %s}' */
 				condition_string = (boost::format(_("%s or ")) % condition_string).str();
 			}
@@ -894,7 +894,7 @@
 			{
 				uint8_t const count = i.current->second;
 				if (1 < count) {
-					// TODO this should be done with ngettext
+					// TODO(unknown) this should be done with ngettext
 					result_string =
 						/** TRANSLATORS: e.g. 'Failed work because: water, wheat (2) are missing' */
 						(boost::format(_("%1$s (%2$i)")) % result_string
@@ -1300,9 +1300,9 @@
 	}
 
 	//  done successful
-	//  FIXME Should pass the time it takes to mine in the phase parameter of
-	//  FIXME ProductionSite::program_step so that the following sleep/animate
-	//  FIXME command knows how long it should last.
+	//  TODO(unknown) Should pass the time it takes to mine in the phase parameter of
+	//  ProductionSite::program_step so that the following sleep/animate
+	//  command knows how long it should last.
 	return ps.program_step(game);
 }
 
@@ -1325,8 +1325,8 @@
 }
 
 ProductionProgram::ActCheck_Soldier::ActCheck_Soldier(char* parameters) {
-	//  FIXME This is currently hardcoded for "soldier", but should allow any
-	//  FIXME soldier type name.
+	//  TODO(unknown) This is currently hardcoded for "soldier", but should allow any
+	//  soldier type name.
 	if (not match_force_skip(parameters, "soldier"))
 		throw game_data_error
 			("expected %s but found \"%s\"", "soldier type", parameters);
@@ -1401,8 +1401,8 @@
 }
 
 ProductionProgram::ActTrain::ActTrain(char* parameters) {
-	//  FIXME This is currently hardcoded for "soldier", but should allow any
-	//  FIXME soldier type name.
+	//  TODO(unknown) This is currently hardcoded for "soldier", but should allow any
+	//  soldier type name.
 	if (not match_force_skip(parameters, "soldier"))
 		throw game_data_error
 			("expected %s but found \"%s\"", "soldier type", parameters);

=== modified file 'src/logic/production_program.h'
--- src/logic/production_program.h	2014-07-14 19:48:07 +0000
+++ src/logic/production_program.h	2014-07-22 10:00:39 +0000
@@ -362,7 +362,7 @@
 	///
 	/// \note It is not possible to reorder ware types within a group. "a,b" is
 	/// equivalent to "b,a" because in the internal representation the ware
-	/// types of a group are sorted. FIXME change this!
+	/// types of a group are sorted. TODO(unknown) change this!
 	struct ActConsume : public Action {
 		ActConsume(char * parameters, const ProductionSite_Descr &);
 		virtual void execute(Game &, ProductionSite &) const override;

=== modified file 'src/logic/save_handler.cc'
--- src/logic/save_handler.cc	2014-07-05 13:14:42 +0000
+++ src/logic/save_handler.cc	2014-07-22 10:00:39 +0000
@@ -72,7 +72,7 @@
 		log("Autosave: interval elapsed (%d s), saving\n", elapsed);
 	}
 
-	// TODO: defer saving to next tick so that this message is shown
+	// TODO(unknown): defer saving to next tick so that this message is shown
 	// before the actual save, or put the saving logic in another thread
 	game.get_ibase()->log_message(_("Saving game..."));
 

=== modified file 'src/logic/ship.cc'
--- src/logic/ship.cc	2014-07-16 08:23:42 +0000
+++ src/logic/ship.cc	2014-07-22 10:00:39 +0000
@@ -372,7 +372,7 @@
 				// NOTE There is a simple check for the current land owner to avoid placement of ports into enemy
 				// NOTE territory, as "clearing" is not yet implemented.
 				// NOTE further it checks, whether there is a Player_immovable on one of the fields.
-				// FIXME handle this more gracefully concering opposing players
+				// TODO(unknown) handle this more gracefully concering opposing players
 				Player_Number pn = get_owner()->player_number();
 				FCoords coord = fc;
 				bool invalid = false;

=== modified file 'src/logic/trainingsite.cc'
--- src/logic/trainingsite.cc	2014-07-14 21:52:13 +0000
+++ src/logic/trainingsite.cc	2014-07-22 10:00:39 +0000
@@ -47,8 +47,8 @@
 	ProductionSite_Descr
 		(_name, _descname, directory, prof, global_s, _tribe, world),
 
-	//  FIXME This is currently hardcoded for "soldier" but should allow any
-	//  FIXME soldier type name.
+	//  TODO(unknown) This is currently hardcoded for "soldier" but should allow any
+	//  soldier type name.
 	m_num_soldiers      (global_s.get_safe_int("soldier_capacity")),
 	m_max_stall (global_s.get_safe_int("trainer_patience")),
 
@@ -66,10 +66,10 @@
 m_max_evade         (0)
 {
 	// Read the range of levels that can update this building
-	//  FIXME This is currently hardcoded to "soldier" but it should search for
-	//  FIXME sections starting with the name of each soldier type.
-	//  FIXME These sections also seem redundant. Eliminate them (having the
-	//  FIXME programs should be enough).
+	//  TODO(unknown) This is currently hardcoded to "soldier" but it should search for
+	//  sections starting with the name of each soldier type.
+	//  These sections also seem redundant. Eliminate them (having the
+	//  programs should be enough).
 	if (Section * const s = prof.get_section("soldier hp")) {
 		m_train_hp      = true;
 		m_min_hp        = s->get_safe_int("min_level");
@@ -731,8 +731,8 @@
 void TrainingSite::calc_upgrades() {
 	assert(m_upgrades.empty());
 
-	//  FIXME This is currently hardcoded for "soldier" but it should allow any
-	//  FIXME soldier type name.
+	//  TODO(unknown) This is currently hardcoded for "soldier" but it should allow any
+	//  soldier type name.
 	if (descr().get_train_hp())
 		add_upgrade(atrHP, "upgrade_soldier_hp_");
 	if (descr().get_train_attack())

=== modified file 'src/logic/trainingsite.h'
--- src/logic/trainingsite.h	2014-07-11 22:53:34 +0000
+++ src/logic/trainingsite.h	2014-07-22 10:00:39 +0000
@@ -53,9 +53,9 @@
 	int32_t get_max_stall() const;
 
 private:
-	//  FIXME These variables should be per soldier type. They should be in a
-	//  FIXME struct and there should be a vector, indexed by Soldier_Index,
-	//  FIXME with that struct structs as element type.
+	//  TODO(unknown) These variables should be per soldier type. They should be in a
+	//  struct and there should be a vector, indexed by Soldier_Index,
+	//  with that struct structs as element type.
 
 	/** Maximum number of soldiers for a training site*/
 	uint32_t m_num_soldiers;

=== modified file 'src/logic/tribe.cc'
--- src/logic/tribe.cc	2014-07-20 13:51:48 +0000
+++ src/logic/tribe.cc	2014-07-22 10:00:39 +0000
@@ -261,7 +261,7 @@
 ===============
 */
 void Tribe_Descr::postload(Editor_Game_Base &) {
-	// TODO: move more loads to postload
+	// TODO(unknown): move more loads to postload
 }
 
 /*

=== modified file 'src/logic/warehouse.cc'
--- src/logic/warehouse.cc	2014-07-16 08:25:35 +0000
+++ src/logic/warehouse.cc	2014-07-22 10:00:39 +0000
@@ -841,13 +841,13 @@
 	m_supply->add_workers(worker_index, 1);
 
 	//  We remove carriers, but we keep other workers around.
-	//  FIXME Remove all workers that do not have properties such as experience.
-	//  FIXME And even such workers should be removed and only a small record
-	//  FIXME with the experience (and possibly other data that must survive)
-	//  FIXME may be kept.
-	//  FIXME When this is done, the get_incorporated_workers method above must
-	//  FIXME be reworked so that workers are recreated, and rescheduled for
-	//  FIXME incorporation.
+	//  TODO(unknown) Remove all workers that do not have properties such as experience.
+	//  And even such workers should be removed and only a small record
+	//  with the experience (and possibly other data that must survive)
+	//  may be kept.
+	//  When this is done, the get_incorporated_workers method above must
+	//  be reworked so that workers are recreated, and rescheduled for
+	//  incorporation.
 	if (upcast(Carrier, carrier, w)) {
 		carrier->remove(egbase);
 		return;

=== modified file 'src/logic/widelands.h'
--- src/logic/widelands.h	2014-07-05 16:41:51 +0000
+++ src/logic/widelands.h	2014-07-22 10:00:39 +0000
@@ -55,7 +55,7 @@
 
 typedef uint16_t Vision;
 
-typedef int32_t Time; // FIXME should be unsigned
+typedef int32_t Time; // TODO(unknown) should be unsigned
 inline Time Never() {return 0xffffffff;}
 
 typedef uint32_t Duration;

=== modified file 'src/logic/worker.cc'
--- src/main.cc	2014-07-15 18:30:46 +0000
+++ src/main.cc	2014-07-22 10:00:39 +0000
@@ -100,7 +100,7 @@
 	WLApplication * g_app = nullptr;
 	try {
 		g_app = WLApplication::get(argc, const_cast<char const * *>(argv));
-		//TODO: handle exceptions from the constructor
+		//TODO(unknown): handle exceptions from the constructor
 		g_app->run();
 
 		delete g_app;

=== modified file 'src/map_io/s2map.cc'
--- src/map_io/s2map.cc	2014-07-14 19:48:07 +0000
+++ src/map_io/s2map.cc	2014-07-22 10:00:39 +0000
@@ -59,7 +59,7 @@
 	char    bulk[2290]; // unknown
 } /* size 2352 */;
 
-// TODO: the following bob types appear in S2 maps but are unknown
+// TODO(unknown): the following bob types appear in S2 maps but are unknown
 //  Somebody who can run Settlers II please check them out
 //  11 (0x0B)
 //  40 (0x28)

=== modified file 'src/map_io/widelands_map_players_view_data_packet.cc'
--- src/map_io/widelands_map_players_view_data_packet.cc	2014-07-14 10:45:44 +0000
+++ src/map_io/widelands_map_players_view_data_packet.cc	2014-07-22 10:00:39 +0000
@@ -169,7 +169,7 @@
 		                      static_cast<long unsigned int>((file).GetSize() - (file).GetPos()),    \
 		                      filename);
 
-// FIXME: Legacy code deprecated since build18
+// TODO(unknown) Legacy code deprecated since build18
 template <uint8_t const Size> struct BitInBuffer {
 	static_assert(Size == 1 or Size == 2 or Size == 4, "Unexpected Size.");
 	BitInBuffer(FileRead* fr) : buffer(0), mask(0x00) {
@@ -458,9 +458,9 @@
 								map_object_descr = nullptr;
 							else if (upcast(Building const, building, base_immovable))
 								if (building->get_position() != f)
-									//  TODO This is not the building's main position
-									//  TODO so we can not see it. But it should be
-									//  TODO possible to see it from a distance somehow.
+									//  TODO(unknown) This is not the building's main position
+									//  so we can not see it. But it should be
+									//  possible to see it from a distance somehow.
 									map_object_descr = nullptr;
 						} else map_object_descr = nullptr;
 						f_player_field.map_object_descr[TCoords<>::None] = map_object_descr;
@@ -601,7 +601,7 @@
 			BORDER_FILENAME_TEMPLATE,
 			BORDER_CURRENT_PACKET_VERSION);
 
-		// FIXME: Legacy code deprecated since build18
+		// TODO(unknown) Legacy code deprecated since build18
 		BitInBuffer<2> legacy_node_immovable_kinds_bitbuffer(&node_immovable_kinds_file);
 		BitInBuffer<2> legacy_road_bitbuffer(&roads_file);
 		BitInBuffer<4> legacy_terrains_bitbuffer(&terrains_file);
@@ -735,9 +735,9 @@
 							map_object_descr = nullptr;
 						else if (upcast(Building const, building, base_immovable))
 							if (building->get_position() != f)
-								//  TODO This is not the building's main position so
-								//  TODO we can not see it. But it should be possible
-								//  TODO to see it from a distance somehow.
+								//  TODO(unknown) This is not the building's main position so
+								//  we can not see it. But it should be possible
+								//  to see it from a distance somehow.
 								map_object_descr = nullptr;
 					} else map_object_descr = nullptr;
 					f_player_field.map_object_descr[TCoords<>::None] = map_object_descr;

=== modified file 'src/map_io/widelands_map_roaddata_data_packet.cc'
--- src/map_io/widelands_map_roaddata_data_packet.cc	2014-07-03 19:26:30 +0000
+++ src/map_io/widelands_map_roaddata_data_packet.cc	2014-07-22 10:00:39 +0000
@@ -258,7 +258,7 @@
 				for (Path::Step_Vector::size_type i = 0; i < nr_steps; ++i)
 					fw.Unsigned8(path[i]);
 
-				fw.Unsigned32(r->m_idle_index); //  FIXME do not save this
+				fw.Unsigned32(r->m_idle_index); //  TODO(unknown) do not save this
 
 
 				fw.Unsigned32(r->m_carrier_slots.size());

=== modified file 'src/map_io/widelands_map_version_data_packet.cc'
--- src/map_io/widelands_map_version_data_packet.cc	2014-05-11 07:38:01 +0000
+++ src/map_io/widelands_map_version_data_packet.cc	2014-07-22 10:00:39 +0000
@@ -113,7 +113,7 @@
 	//
 	// For now, these are meaningless. Let's hope it will not stay that way!
 
-	// FIXME -- we could store the unix time in uint32, as a partial fix to 2038 problem.
+	// TODO(unknown) -- we could store the unix time in uint32, as a partial fix to 2038 problem.
 	// There seems to be a get_safe_natural method, but not corresponding setter.
 
 	Map & map = egbase.map();

=== modified file 'src/network/netclient.h'
--- src/network/netclient.h	2014-07-13 18:20:03 +0000
+++ src/network/netclient.h	2014-07-22 10:00:39 +0000
@@ -27,7 +27,7 @@
 
 struct NetClientImpl;
 
-//FIXME Use composition instead of inheritance
+//TODO(unknown) Use composition instead of inheritance
 /**
  * NetClient manages the lifetime of a network game in which this computer
  * participates as a client.

=== modified file 'src/network/nethost.cc'
--- src/network/nethost.cc	2014-07-16 06:41:27 +0000
+++ src/network/nethost.cc	2014-07-22 10:00:39 +0000
@@ -767,7 +767,7 @@
 
 		while (not d->dedicated_start) {
 			handle_network();
-			// TODO this should be improved.
+			// TODO(unknown) this should be improved.
 #ifndef _WIN32
 			if (d->clients.empty()) {
 				if (usleep(100000)) // Sleep for 0.1 seconds - there is not anybody connected anyways.
@@ -1533,7 +1533,7 @@
 	broadcast(s);
 
 	// If possible, offer the map / saved game as transfer
-	// TODO not yet able to handle directory type maps / savegames
+	// TODO(unknown) not yet able to handle directory type maps / savegames
 	if (!g_fs->IsDirectory(mapfilename)) {
 		// Read in the file
 		FileRead fr;
@@ -1973,7 +1973,7 @@
 * \returns true if the data was written, else false
 */
 bool NetHost::writeMapTransferInfo(SendPacket & s, std::string mapfilename) {
-	// TODO not yet able to handle directory type maps / savegames
+	// TODO(unknown) not yet able to handle directory type maps / savegames
 	if (g_fs->IsDirectory(mapfilename)) {
 		dedicatedlog("Map/Save is a directory! No way for making it available a.t.m.!\n");
 		return false;

=== modified file 'src/profile/profile.h'
--- src/profile/profile.h	2014-07-14 19:24:12 +0000
+++ src/profile/profile.h	2014-07-22 10:00:39 +0000
@@ -26,7 +26,8 @@
 #include "base/macros.h"
 #include "base/point.h"
 #include "io/filesystem/layered_filesystem.h"
-//TODO: as soon as g_fs is not needed anymore, include "filesystem.h" instead of layered_filesystem.h.
+// TODO(unknown): as soon as g_fs is not needed anymore,
+// include "filesystem.h" instead of layered_filesystem.h.
 
 extern class Profile g_options;
 class FileSystem;

=== modified file 'src/scripting/lua_map.cc'
--- src/scripting/lua_map.cc	2014-07-17 14:49:37 +0000
+++ src/scripting/lua_map.cc	2014-07-22 10:00:39 +0000
@@ -987,7 +987,7 @@
 		and so on. You only need to call this function if you changed
 		Field.raw_height in any way.
 */
-// TODO: do we really want this function?
+// TODO(unknown): do we really want this function?
 int L_Map::recalculate(lua_State * L) {
 	Editor_Game_Base & egbase = get_egbase(L);
 	egbase.map().recalc_whole_map(egbase.world());
@@ -1106,7 +1106,7 @@
 	PROP_RO(L_BuildingDescription, is_port),
 	PROP_RO(L_BuildingDescription, returned_wares),
 	PROP_RO(L_BuildingDescription, returned_wares_enhanced),
-	// TODO size should be similar to
+	// TODO(SirVer) size should be similar to
 	// https://wl.widelands.org/docs/wl/autogen_wl_map/#wl.map.BaseImmovable.size.
 	// In fact, as soon as all descriptions are wrapped (also for other
 	// immovables besides buildings) we should get rid of BaseImmovable.size.

=== modified file 'src/sound/songset.cc'
--- src/sound/songset.cc	2014-06-18 13:20:33 +0000
+++ src/sound/songset.cc	2014-07-22 10:00:39 +0000
@@ -27,9 +27,11 @@
 #include "sound/sound_handler.h"
 
 namespace {
-	// The behaviour of whether SDL_Mixer frees the RW it uses was changed with SDL_Mixer version 1.2.12, this
+	// The behaviour of whether SDL_Mixer frees the RW it uses was
+	// changed with SDL_Mixer version 1.2.12, this
 	// check is so that we don't have a memory leak in the new version.
-	// TODO: Once we can demand that everyone use SDL_Mixer version >= 1.2.12, this function should be removed,
+	// TODO(unknown): Once we can demand that everyone use
+	// SDL_Mixer version >= 1.2.12, this function should be removed,
 	// and all usages replaced supposing it's true.
 	bool have_to_free_rw() {
 		return

=== modified file 'src/sound/sound_handler.cc'
--- src/sound/sound_handler.cc	2014-07-14 10:45:44 +0000
+++ src/sound/sound_handler.cc	2014-07-22 10:00:39 +0000
@@ -358,16 +358,16 @@
 	//  float division! not integer
 	probability = (priority % PRIO_ALLOW_MULTIPLE) / 128.0;
 
-	//TODO: what to do with fx that happen offscreen?
-	//TODO: reduce volume? reduce priority? other?
+	//TODO(unknown): what to do with fx that happen offscreen?
+	//TODO(unknown): reduce volume? reduce priority? other?
 	if (stereo_pos == -1) {
 		return false;
 	}
 
-	//TODO: check for a free channel
+	//TODO(unknown): check for a free channel
 
 	if (priority == PRIO_ALWAYS_PLAY) {
-		//TODO: if there is no free channel, kill a running fx and complain
+		//TODO(unknown): if there is no free channel, kill a running fx and complain
 		return true;
 	}
 
@@ -392,9 +392,9 @@
 	if (!allow_multiple && already_running)
 		return false;
 
-	//TODO: long time since any play increases weighted_priority
-	//TODO: high general frequency reduces weighted priority
-	//TODO: deal with "coupled" effects like throw_net and retrieve_net
+	//TODO(unknown): long time since any play increases weighted_priority
+	//TODO(unknown): high general frequency reduces weighted priority
+	//TODO(unknown): deal with "coupled" effects like throw_net and retrieve_net
 
 	uint32_t const ticks_since_last_play =
 		SDL_GetTicks() - fxs_[fx_name]->last_used_;

=== modified file 'src/third_party/eris/eris.c'
--- src/third_party/eris/eris.c	2014-02-22 14:47:28 +0000
+++ src/third_party/eris/eris.c	2014-07-22 10:00:39 +0000
@@ -801,7 +801,7 @@
 u_string(Info *info) {                                                 /* ... */
   eris_checkstack(info->L, 2);
   {
-    /* TODO Can we avoid this copy somehow? (Without it getting too nasty) */
+	 /* TODO(unknown) Can we avoid this copy somehow? (Without it getting too nasty) */
     const size_t length = READ_VALUE(size_t);
     char *value = lua_newuserdata(info->L, length * sizeof(char)); /* ... tmp */
     READ_RAW(value, length);
@@ -1647,7 +1647,7 @@
   WRITE_VALUE(thread->hookcount, int); */
 
   if (thread->hook) {
-    /* TODO Warn that hooks are not persisted? */
+	 /* TODO(unknown) Warn that hooks are not persisted? */
   }
 
   /* Write call information (stack frames). In 5.2 CallInfo is stored in a
@@ -1694,7 +1694,7 @@
       WRITE_VALUE(ci->u.c.old_errfunc, ptrdiff_t);
       WRITE_VALUE(ci->u.c.old_allowhook, uint8_t); */
 
-      /* TODO Is this really right? Hooks may be a problem? */
+		/* TODO(unknown) Is this really right? Hooks may be a problem? */
       if (ci->callstatus & (CIST_YPCALL | CIST_YIELDED)) {
         WRITE_VALUE(ci->u.c.ctx, int);
         eris_assert(ci->u.c.k);
@@ -1867,7 +1867,7 @@
       thread->ci->u.c.old_errfunc = 0;
       thread->ci->u.c.old_allowhook = 0;
 
-      /* TODO Is this really right? */
+		/* TODO(unknown) Is this really right? */
       if (thread->ci->callstatus & (CIST_YPCALL | CIST_YIELDED)) {
         thread->ci->u.c.ctx = READ_VALUE(int);
         LOCK(thread);

=== modified file 'src/ui_basic/panel.cc'
--- src/ui_basic/panel.cc	2014-07-14 10:45:44 +0000
+++ src/ui_basic/panel.cc	2014-07-22 10:00:39 +0000
@@ -998,9 +998,9 @@
 	if (_flags & pf_top_on_click)
 		move_to_top();
 
-	//  FIXME This code is erroneous. It checks the current key state. What it
-	//  FIXME needs is the key state at the time the mouse was clicked. See the
-	//  FIXME usage comment for get_key_state.
+	//  TODO(unknown) This code is erroneous. It checks the current key state. What it
+	//  needs is the key state at the time the mouse was clicked. See the
+	//  usage comment for get_key_state.
 	//  Some window managers use alt-drag, so we can't only use the alt keys
 	if
 		((not _g_mousegrab) && (btn == SDL_BUTTON_LEFT) &&

=== modified file 'src/ui_basic/progressbar.cc'
--- src/ui_basic/progressbar.cc	2014-07-05 14:22:44 +0000
+++ src/ui_basic/progressbar.cc	2014-07-22 10:00:39 +0000
@@ -104,7 +104,7 @@
 	}
 
 	// Print the state in percent
-	// TODO use UI_FNT_COLOR_BRIGHT when merged
+	// TODO(unknown) use UI_FNT_COLOR_BRIGHT when merged
 	uint32_t percent = static_cast<uint32_t>(fraction * 100);
 	const std::string progress_text =
 		(boost::format("<font color=%1$s>%2$i%%</font>") % "ffffff" % percent).str();

=== modified file 'src/ui_basic/slider.cc'
--- src/ui_basic/slider.cc	2014-07-14 10:45:44 +0000
+++ src/ui_basic/slider.cc	2014-07-22 10:00:39 +0000
@@ -202,7 +202,7 @@
  */
 void Slider::set_enabled(const bool enabled)
 {
-	//  TODO: disabled should look different...
+	// TODO(unknown) disabled should look different...
 	if (m_enabled == enabled)
 		return;
 

=== modified file 'src/ui_basic/tabpanel.cc'
--- src/ui_basic/tabpanel.cc	2014-07-14 10:45:44 +0000
+++ src/ui_basic/tabpanel.cc	2014-07-22 10:00:39 +0000
@@ -125,7 +125,7 @@
 		uint32_t panelw, panelh;
 
 		panel->get_desired_size(panelw, panelh);
-		// TODO  the panel might be bigger -> add a scrollbar in that case
+		// TODO(unknown)  the panel might be bigger -> add a scrollbar in that case
 		//panel->set_size(panelw, panelh);
 
 		if (panelw > w)

=== modified file 'src/ui_basic/window.cc'
--- src/ui_basic/window.cc	2014-07-14 10:45:44 +0000
+++ src/ui_basic/window.cc	2014-07-22 10:00:39 +0000
@@ -432,9 +432,9 @@
  */
 bool Window::handle_mousepress(const uint8_t btn, int32_t mx, int32_t my)
 {
-	//  FIXME This code is erroneous. It checks the current key state. What it
-	//  FIXME needs is the key state at the time the mouse was clicked. See the
-	//  FIXME usage comment for get_key_state.
+	//  TODO(unknown) This code is erroneous. It checks the current key state. What it
+	//  needs is the key state at the time the mouse was clicked. See the
+	//  usage comment for get_key_state.
 	if
 		(((get_key_state(SDLK_LCTRL) | get_key_state(SDLK_RCTRL))
 		  and

=== modified file 'src/ui_fsmenu/netsetup_lan.cc'
--- src/ui_fsmenu/netsetup_lan.cc	2014-07-05 14:22:44 +0000
+++ src/ui_fsmenu/netsetup_lan.cc	2014-07-22 10:00:39 +0000
@@ -28,7 +28,7 @@
 #include "wui/text_constants.h"
 
 Fullscreen_Menu_NetSetupLAN::Fullscreen_Menu_NetSetupLAN () :
-	Fullscreen_Menu_Base("singleplmenu.jpg"), //  FIXME change this
+	Fullscreen_Menu_Base("singleplmenu.jpg"), //  TODO(unknown) change this
 
 // Values for alignment and size
 	m_butx (get_w() * 13 / 40),

=== modified file 'src/ui_fsmenu/options.cc'
--- src/ui_fsmenu/options.cc	2014-07-05 14:22:44 +0000
+++ src/ui_fsmenu/options.cc	2014-07-22 10:00:39 +0000
@@ -290,7 +290,7 @@
 	m_label_autosave                 .set_textstyle(ts_small());
 	m_label_remove_replays           .set_textstyle(ts_small());
 
-	//  GRAPHIC_TODO: this shouldn't be here List all resolutions
+	//  GRAPHIC_TODO(unknown): this shouldn't be here List all resolutions
 	// take a copy to not change real video info structure
 	SDL_PixelFormat fmt = *SDL_GetVideoInfo()->vfmt;
 	fmt.BitsPerPixel = 32;

=== modified file 'src/wlapplication.cc'
--- src/wui/chatoverlay.cc	2014-07-16 06:41:27 +0000
+++ src/wui/chatoverlay.cc	2014-07-22 10:00:39 +0000
@@ -181,7 +181,7 @@
 	const int32_t top = get_h() - height - 2 * MARGIN;
 	const int width = std::min<int>(get_w(), im->width());
 
-	//FIXME: alpha channel not respected
+	// TODO(unknown) alpha channel not respected
 	if (!m->transparent_) {
 		Rect rect(0, top, width, height);
 		dst.fill_rect(rect, RGBAColor(50, 50, 50, 128));

=== modified file 'src/wui/encyclopedia_window.cc'
--- src/wui/encyclopedia_window.cc	2014-07-03 20:11:14 +0000
+++ src/wui/encyclopedia_window.cc	2014-07-22 10:00:39 +0000
@@ -145,12 +145,12 @@
 			(*tribe.get_building_descr(prodSites.get_selected()))
 		.programs();
 
-	//  FIXME This needs reworking. A program can indeed produce iron even if
-	//  FIXME the program name is not any of produce_iron, smelt_iron, prog_iron
-	//  FIXME or work. What matters is whether the program has a statement such
-	//  FIXME as "produce iron" or "createware iron". The program name is not
-	//  FIXME supposed to have any meaning to the game logic except to uniquely
-	//  FIXME identify the program.
+	//  TODO(unknown) This needs reworking. A program can indeed produce iron even if
+	//  the program name is not any of produce_iron, smelt_iron, prog_iron
+	//  or work. What matters is whether the program has a statement such
+	//  as "produce iron" or "createware iron". The program name is not
+	//  supposed to have any meaning to the game logic except to uniquely
+	//  identify the program.
 	//  Only shows information from the first program that has a name indicating
 	//  that it produces the considered ware type.
 	std::map<std::string, ProductionProgram *>::const_iterator programIt =

=== modified file 'src/wui/game_main_menu_save_game.cc'
--- src/wui/game_main_menu_save_game.cc	2014-07-05 14:22:44 +0000
+++ src/wui/game_main_menu_save_game.cc	2014-07-22 10:00:39 +0000
@@ -134,7 +134,7 @@
 		m_gametime.set_text(gametimestring(gametime));
 
 		int player_nr = parent.game().player_manager()->get_number_of_players();
-		// TODO: This should be ngettext(" %i player" etc. with boost::format, but it refuses to work
+		// TODO(GunChleoc): This should be ngettext(" %i player" etc. with boost::format, but it refuses to work
 		/** TRANSLATORS: This is preceded by a number */
 		m_players_label.set_text(
 		   (boost::format(ngettext("%i player", "%i players", player_nr)) % player_nr).str());
@@ -174,7 +174,8 @@
 		char buf[200];
 		sprintf
 			(buf, "%i %s", gpdp.get_number_of_players(),
-			// TODO: This should be ngettext(" %i player" etc. with boost::format, but it refuses to work
+			// TODO(GunChleoc): This should be ngettext(" %i player" etc.
+			// with boost::format, but it refuses to work
 			/** TRANSLATORS: This is preceded by a number */
 			ngettext("player", "players", gpdp.get_number_of_players()));
 			m_players_label.set_text(buf);

=== modified file 'src/wui/game_message_menu.cc'
--- src/wui/game_message_menu.cc	2014-07-05 13:14:42 +0000
+++ src/wui/game_message_menu.cc	2014-07-22 10:00:39 +0000
@@ -186,8 +186,8 @@
 	if (list->size()) {
 		if (not list->has_selection())
 			list->select(0);
-			// FIXME Workaround for bug #691928: There should
-			// FIXME be a solution without this extra update().
+			// TODO(unknown) Workaround for bug #691928: There should
+			// be a solution without this extra update().
 			list->update();
 	} else {
 		m_centerviewbtn->set_enabled(false);

=== modified file 'src/wui/interactive_base.cc'
--- src/wui/interactive_base.cc	2014-07-21 08:27:25 +0000
+++ src/wui/interactive_base.cc	2014-07-22 10:00:39 +0000
@@ -406,7 +406,12 @@
 		static format node_format("(%i, %i)");
 		const std::string node_text = as_uifont
 			((node_format % m_sel.pos.node.x % m_sel.pos.node.y).str(), UI_FONT_SIZE_SMALL);
-		dst.blit(Point(get_w() - 5, get_h() - 5), UI::g_fh1->render(node_text), CM_Normal, UI::Align_BottomRight);
+		dst.blit(
+			Point(get_w() - 5, get_h() - 5),
+			UI::g_fh1->render(node_text),
+			CM_Normal,
+			UI::Align_BottomRight
+		);
 	}
 
 	// Blit FPS when in debug mode.

=== modified file 'src/wui/interactive_player.cc'
--- src/wui/interactive_player.cc	2014-07-15 17:29:28 +0000
+++ src/wui/interactive_player.cc	2014-07-22 10:00:39 +0000
@@ -145,7 +145,7 @@
 	m_toggle_help.sigclicked.connect
 		(boost::bind(&UI::UniqueWindow::Registry::toggle, boost::ref(m_encyclopedia)));
 
-	// TODO : instead of making unneeded buttons invisible after generation,
+	// TODO(unknown) : instead of making unneeded buttons invisible after generation,
 	// they should not at all be generated. -> implement more dynamic toolbar UI
 	m_toolbar.add(&m_toggle_options_menu,    UI::Box::AlignLeft);
 	m_toolbar.add(&m_toggle_statistics_menu, UI::Box::AlignLeft);

=== modified file 'src/wui/interactive_spectator.cc'
--- src/wui/interactive_spectator.cc	2014-07-13 18:20:03 +0000
+++ src/wui/interactive_spectator.cc	2014-07-22 10:00:39 +0000
@@ -77,7 +77,7 @@
 	m_toolbar.add(&m_toggle_minimap,         UI::Box::AlignLeft);
 	m_toolbar.add(&m_toggle_chat,            UI::Box::AlignLeft);
 
-	// TODO : instead of making unneeded buttons invisible after generation,
+	// TODO(unknown) : instead of making unneeded buttons invisible after generation,
 	// they should not at all be generated. -> implement more dynamic toolbar UI
 	if (is_multiplayer()) {
 		m_exit.set_visible(false);

=== modified file 'src/wui/portdockwaresdisplay.cc'
--- src/wui/portdockwaresdisplay.cc	2014-04-21 10:47:03 +0000
+++ src/wui/portdockwaresdisplay.cc	2014-07-22 10:00:39 +0000
@@ -80,7 +80,7 @@
 		box.add(new WaresQueueDisplay(&box, 0, 0, igb, wh, wq, true), UI::Box::AlignLeft);
 	}
 
-/* FIXME Implement UI for Builder + Soldiers
+/* TODO(unknown) Implement UI for Builder + Soldiers
 	UI::Box & workers = *new UI::Box(&box, 0, 0, UI::Box::Horizontal);
 	box.add(&workers, UI::Box::AlignLeft);
 

=== modified file 'src/wui/ware_statistics_menu.cc'
--- src/wui/ware_statistics_menu.cc	2014-07-05 14:22:44 +0000
+++ src/wui/ware_statistics_menu.cc	2014-07-22 10:00:39 +0000
@@ -42,7 +42,7 @@
 static const char pic_tab_production[] = "pics/menu_tab_wares_production.png";
 static const char pic_tab_consumption[] = "pics/menu_tab_wares_consumption.png";
 static const char pic_tab_economy[] = "pics/menu_tab_wares_econ_health.png";
-static const char pic_tab_stock[] = "pics/menu_tab_wares_stock.png"; //TODO replace place holder
+static const char pic_tab_stock[] = "pics/menu_tab_wares_stock.png"; // TODO(unknown) replace place holder
 
 static const RGBColor colors[] = {
 	RGBColor(115, 115, 115), //inactive

=== modified file 'src/wui/waresdisplay.cc'
--- src/wui/waresdisplay.cc	2014-07-14 10:45:44 +0000
+++ src/wui/waresdisplay.cc	2014-07-22 10:00:39 +0000
@@ -104,7 +104,7 @@
 		// Ensure mouse button is still pressed as some
 		// mouse release events do not reach us
 		if (state ^ SDL_BUTTON_LMASK) {
-			// FIXME: We should call another function that will not pass that events
+			// TODO(unknown) We should call another function that will not pass that events
 			// to our Panel superclass
 			handle_mouserelease(SDL_BUTTON_LEFT, x, y);
 			return true;
@@ -351,7 +351,7 @@
 	if (m_selection_anchor != Widelands::INVALID_INDEX) {
 		// Draw the temporary selected wares as if they were
 		// selected.
-		// TODO: Use another pic for the temporary selection
+		// TODO(unknown): Use another pic for the temporary selection
 		if (!ware_selected(m_selection_anchor)) {
 			draw_selected |= m_in_selection[id];
 		} else {


Follow ups
--- src/economy/wares_queue.cc	2014-06-01 18:00:48 +0000
+++ src/economy/wares_queue.cc	2014-07-22 10:00:39 +0000
@@ -269,13 +269,13 @@
 			m_filled           =                            fr.Unsigned32();
 			m_consume_interval =                            fr.Unsigned32();
 			if                                             (fr.Unsigned8 ()) {
-				m_request =                          //  FIXME Change Request::Read
-					new Request                       //  FIXME to a constructor.
-						(m_owner,                      //  FIXME
-						 0,          //  FIXME
-						 WaresQueue::request_callback, //  FIXME
-						 wwWORKER);             //  FIXME
-				m_request->Read(fr, game, mol);      //  FIXME
+				m_request =                          //  TODO(unknown) Change Request::Read
+					new Request                       //  TODO(unknown) to a constructor.
+						(m_owner,                      //  TODO(unknown)
+						 0,          //  TODO(unknown)
+						 WaresQueue::request_callback, //  TODO(unknown)
+						 wwWORKER);             //  TODO(unknown)
+				m_request->Read(fr, game, mol);      //  TODO(unknown)
 			} else
 				m_request = nullptr;
 

=== modified file 'src/editor/editorinteractive.cc'
--- src/io/filesystem/disk_filesystem.cc	2014-07-15 19:50:41 +0000
+++ src/io/filesystem/disk_filesystem.cc	2014-07-22 10:00:39 +0000
@@ -70,7 +70,7 @@
 RealFSImpl::RealFSImpl(const std::string & Directory)
 : m_directory(Directory)
 {
 	// TODO: check OS permissions on whether the directory is writable!
 	m_root = FS_CanonicalizeName(Directory);
 }
 
@@ -189,7 +189,7 @@
  */
 FileSystem * RealFSImpl::MakeSubFileSystem(const std::string & path) {
 	FileSystemPath fspath(FS_CanonicalizeName(path));
-	assert(fspath.m_exists); //TODO: throw an exception instead
+	assert(fspath.m_exists); //TODO(unknown): throw an exception instead
 
 	if (fspath.m_isDirectory)
 		return new RealFSImpl   (fspath);
@@ -234,8 +234,8 @@
  */
 void RealFSImpl::m_unlink_file(const std::string & file) {
 	FileSystemPath fspath(FS_CanonicalizeName(file));
-	assert(fspath.m_exists);  //TODO: throw an exception instead
-	assert(!fspath.m_isDirectory); //TODO: throw an exception instead
+	assert(fspath.m_exists);  //TODO(unknown): throw an exception instead
+	assert(!fspath.m_isDirectory); //TODO(unknown): throw an exception instead
 
 #ifndef _WIN32
 	unlink(fspath.c_str());
@@ -249,8 +249,8 @@
  */
 void RealFSImpl::m_unlink_directory(const std::string & file) {
 	FileSystemPath fspath(FS_CanonicalizeName(file));
-	assert(fspath.m_exists);  //TODO: throw an exception instead
-	assert(fspath.m_isDirectory);  //TODO: throw an exception instead
+	assert(fspath.m_exists);  //TODO(unknown): throw an exception instead
+	assert(fspath.m_isDirectory);  //TODO(unknown): throw an exception instead
 
 	filenameset_t files = ListDirectory(file);
 	for
@@ -372,7 +372,7 @@
 		fseek(file, 0, SEEK_SET);
 
 		// allocate a buffer and read the entire file into it
-		data = malloc(size + 1); //  FIXME memory leak!
+		data = malloc(size + 1); //  TODO(unknown) memory leak!
 		int result = fread(data, size, 1, file);
 		if (size and (result != 1)) {
 			throw wexception
@@ -70,7 +70,7 @@
 : m_directory(Directory)
 {
-	// TODO: check OS permissions on whether the directory is writable!
+	// TODO(unknown): check OS permissions on whether the directory is writable!
 	m_root = FS_CanonicalizeName(Directory);
 }

=== modified file 'src/io/filesystem/filesystem.cc'
--- src/io/filesystem/filesystem.cc	2014-06-14 19:36:03 +0000
+++ src/io/filesystem/filesystem.cc	2014-07-22 10:00:39 +0000
@@ -182,7 +182,7 @@
 			("\nWARNING: either we can not detect your home directory "
 			 "or you do not have one! Please contact the developers.\n\n");
 
 		//TODO: is it really a good idea to set homedir to "." then ??
 
 		log("Instead of your home directory, '.' will be used.\n\n");
 		homedir = ".";
@@ -385,7 +385,7 @@
 	if (S_ISDIR(statinfo.st_mode)) {
 		return *new RealFSImpl(root);
 	}
-	if (S_ISREG(statinfo.st_mode)) { //TODO: ensure root is a zipfile
+	if (S_ISREG(statinfo.st_mode)) { //TODO(unknown): ensure root is a zipfile
 		return *new ZipFilesystem(root);
 	}
 
@@ -182,7 +182,7 @@
 			 "or you do not have one! Please contact the developers.\n\n");
 
-		//TODO: is it really a good idea to set homedir to "." then ??
+		//TODO(unknown): is it really a good idea to set homedir to "." then ??
 
 		log("Instead of your home directory, '.' will be used.\n\n");

=== modified file 'src/io/filesystem/filesystem.h'
--- src/io/filesystem/zip_filesystem.cc	2014-06-01 18:00:48 +0000
+++ src/io/filesystem/zip_filesystem.cc	2014-07-22 10:00:39 +0000
@@ -46,7 +46,7 @@
 m_basenamezip(FS_Filename(zipfile.c_str())),
 m_basename   ()
 {
 	// TODO: check OS permissions on whether the file is writable
 }
 
 /**
@@ -100,9 +100,9 @@
 			complete_filename.substr
 				(0, complete_filename.size() - filename.size());
 
 		//  FIXME Something strange is going on with regard to the leading slash!
 		//  FIXME This is just an ugly workaround and does not solve the real
 		//  FIXME problem (which remains undiscovered)
 		if
 			(('/' + path == filepath || path == filepath || path.length() == 1)
 			 && filename.size())
@@ -120,7 +120,7 @@
  */
 bool ZipFilesystem::FileExists(const std::string & path) {
 	try {
-		m_OpenUnzip(); //  FIXME check return value
+		m_OpenUnzip(); //  TODO(unknown) check return value
 	} catch (...) {
 		return false;
 	}
@@ -559,7 +559,7 @@
 }
 
 unsigned long long ZipFilesystem::DiskSpace() {
-	return 0; //  FIXME
+	return 0; //  TODO(unknown)
 }
 
 std::string ZipFilesystem::strip_basename(std::string filename)
@@ -46,7 +46,7 @@
 m_basename   ()
 {
-	// TODO: check OS permissions on whether the file is writable
+	// TODO(unknown): check OS permissions on whether the file is writable
 }
 
@@ -100,9 +100,9 @@
 				(0, complete_filename.size() - filename.size());
 
-		//  FIXME Something strange is going on with regard to the leading slash!
-		//  FIXME This is just an ugly workaround and does not solve the real
-		//  FIXME problem (which remains undiscovered)
+		//  TODO(unknown) Something strange is going on with regard to the leading slash!
+		//  This is just an ugly workaround and does not solve the real
+		//  problem (which remains undiscovered)
 		if
 			(('/' + path == filepath || path == filepath || path.length() == 1)

=== modified file 'src/io/streamwrite.h'
--- src/logic/worker.cc	2014-07-17 09:15:53 +0000
+++ src/logic/worker.cc	2014-07-22 10:00:39 +0000
@@ -115,7 +115,7 @@
 	//Make sure that the specified resource is available in this world
 	Resource_Index const res =
 		game.world().get_resource(action.sparam1.c_str());
-	if (static_cast<int8_t>(res) == -1) //  FIXME ARGH!!
+	if (static_cast<int8_t>(res) == -1) //  TODO(unknown) ARGH!!
 		throw game_data_error
 			(_
 			 	("should mine resource %s, which does not exist in world; tribe "
@@ -206,7 +206,7 @@
  * \param action Which resource to breed (action.sparam1) and where to put
  * it (in a radius of action.iparam1 around current location)
  *
  * FIXME: in FindNodeResourceBreedable, the node (or neighbors) is accepted if it is breedable.
  * In here, breeding may happen on a node emptied of resource.
  * \todo Lots of magic numbers in here
  * \todo Document parameters g and state
@@ -220,7 +220,7 @@
 	//Make sure that the specified resource is available in this world
 	Resource_Index const res =
 		game.world().get_resource(action.sparam1.c_str());
-	if (static_cast<int8_t>(res) == -1) //  FIXME ARGH!!
+	if (static_cast<int8_t>(res) == -1) //  TODO(unknown) ARGH!!
 		throw game_data_error
 			(_
 			 	("should breed resource type %s, which does not exist in world; "
@@ -496,23 +496,24 @@
  * Find only nodes that are walkable such that all neighbours
  * are also walkable (an exception is made if one of the neighbouring
  * fields is owned by this worker's location).
  * FIXME This is an embarrasingly ugly hack to make bug #1796611 happen less
  * FIXME often. But it gives no passability guarantee (that workers will not
  * FIXME get locked in). For example one farmer may call findspace and then,
  * FIXME before he plants anything, another farmer may call findspace, which
  * FIXME may find a space without considering that the first farmer will plant
  * FIXME something. Together they can cause a passability problem. This code
  * FIXME will also allow blocking the shoreline if it is next to the worker's
  * FIXME location. Also, the gap of 2 nodes between 2 farms will be blocked,
  * FIXME because both are next to their farm. The only real solution that I can
  * FIXME think of for this kind of bugs is to only allow unpassable objects to
  * FIXME be placed on a node if ALL neighbouring nodes are passable. This must
  * FIXME of course be checked at the moment when the object is placed and not,
  * FIXME as in this case, only before a worker starts walking there to place an
  * FIXME object. But that would make it very difficult to find space for things
  * FIXME like farm fileds. So our only option seems to be to keep all farm
  * FIXME fields, trees, stones and such on triangles and keep the nodes
  * FIXME passable. See code structure issue #1096824.
  *
  * iparam1 = radius
  * iparam2 = FindNodeSize::sizeXXX
@@ -605,7 +606,7 @@
 	if (building.descr().name() == "fish_breeders_house")
 		return;
 
 	// TODO "stone" is defined as "granite" in the world. But this code is
 	// erroneus anyways: it translates immovable attribute stone as resource
 	// granite. Instead, the immovable attributes should be made translatable in
 	// the world or the quarry should define its out of stone message in its
@@ -759,10 +760,10 @@
 		immovable->switch_program(game, action.sparam1);
 	else if (upcast(Bob,       bob,       obj)) {
 		if        (upcast(Critter_Bob, crit, bob)) {
-			crit->reset_tasks(game); //  TODO ask the critter more nicely
+			crit->reset_tasks(game); //  TODO(unknown) ask the critter more nicely
 			crit->start_task_program(game, action.sparam1);
 		} else if (upcast(Worker,      w,    bob)) {
-			w   ->reset_tasks(game); //  TODO  ask the worker more nicely
+			w   ->reset_tasks(game); //  TODO(unknown) ask the worker more nicely
 			w   ->start_task_program(game, action.sparam1);
 		} else
 			throw wexception
@@ -2759,7 +2760,7 @@
 					 	 descr().get_right_walk_anims(does_carry_ware())))
 				{
 
-					molog("[geologist]: BUG: could not find path\n");
+					molog("[geologist]: BUG(unknown): could not find path\n");
 					send_signal(game, "fail");
 					return pop_task(game);
 				}
@@ -206,7 +206,7 @@
  * it (in a radius of action.iparam1 around current location)
  *
- * FIXME: in FindNodeResourceBreedable, the node (or neighbors) is accepted if it is breedable.
+ * TODO(unknown) in FindNodeResourceBreedable, the node (or neighbors) is accepted if it is breedable.
  * In here, breeding may happen on a node emptied of resource.
  * \todo Lots of magic numbers in here
@@ -496,23 +496,24 @@
  * are also walkable (an exception is made if one of the neighbouring
  * fields is owned by this worker's location).
- * FIXME This is an embarrasingly ugly hack to make bug #1796611 happen less
- * FIXME often. But it gives no passability guarantee (that workers will not
- * FIXME get locked in). For example one farmer may call findspace and then,
- * FIXME before he plants anything, another farmer may call findspace, which
- * FIXME may find a space without considering that the first farmer will plant
- * FIXME something. Together they can cause a passability problem. This code
- * FIXME will also allow blocking the shoreline if it is next to the worker's
- * FIXME location. Also, the gap of 2 nodes between 2 farms will be blocked,
- * FIXME because both are next to their farm. The only real solution that I can
- * FIXME think of for this kind of bugs is to only allow unpassable objects to
- * FIXME be placed on a node if ALL neighbouring nodes are passable. This must
- * FIXME of course be checked at the moment when the object is placed and not,
- * FIXME as in this case, only before a worker starts walking there to place an
- * FIXME object. But that would make it very difficult to find space for things
- * FIXME like farm fileds. So our only option seems to be to keep all farm
- * FIXME fields, trees, stones and such on triangles and keep the nodes
- * FIXME passable. See code structure issue #1096824.
+ *
+ * TODO(unknown) This is an embarrasingly ugly hack to make bug #1796611 happen less
+ * often. But it gives no passability guarantee (that workers will not
+ * get locked in). For example one farmer may call findspace and then,
+ * before he plants anything, another farmer may call findspace, which
+ * may find a space without considering that the first farmer will plant
+ * something. Together they can cause a passability problem. This code
+ * will also allow blocking the shoreline if it is next to the worker's
+ * location. Also, the gap of 2 nodes between 2 farms will be blocked,
+ * because both are next to their farm. The only real solution that I can
+ * think of for this kind of bugs is to only allow unpassable objects to
+ * be placed on a node if ALL neighbouring nodes are passable. This must
+ * of course be checked at the moment when the object is placed and not,
+ * as in this case, only before a worker starts walking there to place an
+ * object. But that would make it very difficult to find space for things
+ * like farm fileds. So our only option seems to be to keep all farm
+ * fields, trees, stones and such on triangles and keep the nodes
+ * passable. See code structure issue #1096824.
  *
  * iparam1 = radius
@@ -605,7 +606,7 @@
 		return;
 
-	// TODO "stone" is defined as "granite" in the world. But this code is
+	// TODO(unknown) "stone" is defined as "granite" in the world. But this code is
 	// erroneus anyways: it translates immovable attribute stone as resource
 	// granite. Instead, the immovable attributes should be made translatable in

=== modified file 'src/main.cc'
--- src/wlapplication.cc	2014-07-14 10:45:44 +0000
+++ src/wlapplication.cc	2014-07-22 10:00:39 +0000
@@ -137,7 +137,7 @@
 		log("Access denied on %s. Continuing.\n", e.m_filename.c_str());
 	}
 	catch (FileType_error &) {
-		//TODO: handle me
+		//TODO(unknown): handle me
 	}
 
 	try {
@@ -152,7 +152,7 @@
 		log("Access denied on %s. Continuing.\n", e.m_filename.c_str());
 	}
 	catch (FileType_error &) {
-		//TODO: handle me
+		//TODO(unknown): handle me
 	}
 
 	try {
@@ -170,10 +170,10 @@
 		log("Access denied on %s. Continuing.\n", e.m_filename.c_str());
 	}
 	catch (FileType_error &) {
-		//TODO: handle me
+		//TODO(unknown): handle me
 	}
 
 	//TODO: what if all the searching failed? Bail out!
 
 	// the directory the executable is in is the default game data directory
 	std::string::size_type slash = argv0.rfind('/');
@@ -196,7 +196,7 @@
 				log ("Access denied on %s. Continuing.\n", e.m_filename.c_str());
 			}
 			catch (FileType_error &) {
-				//TODO: handle me
+				//TODO(unknown): handle me
 			}
 		}
 	}
@@ -216,7 +216,7 @@
 			log("Failed to add home directory: %s\n", e.what());
 		}
 	} else {
-		//TODO: complain
+		//TODO(unknown): complain
 	}
 }
 
@@ -340,7 +340,7 @@
 
 	SDLNet_Quit();
 
-	TTF_Quit(); // TODO not here
+	TTF_Quit(); // TODO(unknown) not here
 
 	assert(g_fs);
 	delete g_fs;
@@ -692,7 +692,7 @@
 		SDL_WM_GrabInput(SDL_GRAB_ON);
 	} else {
 		SDL_WM_GrabInput(SDL_GRAB_OFF);
-		warp_mouse(m_mouse_position); //TODO: is this redundant?
+		warp_mouse(m_mouse_position); //TODO(unknown): is this redundant?
 	}
 }
 
@@ -954,7 +954,7 @@
 
 	// Start the audio subsystem
 	// must know the locale before calling this!
-	g_sound_handler.init(); //  FIXME memory leak!
+	g_sound_handler.init(); //  TODO(unknown) memory leak!
 
 	return true;
 }
@@ -996,7 +996,7 @@
 void WLApplication::parse_commandline
 	(int const argc, char const * const * const argv)
 {
 	//TODO: EXENAME gets written out on windows!
 	m_commandline["EXENAME"] = argv[0];
 
 	for (int i = 1; i < argc; ++i) {
@@ -1042,7 +1042,7 @@
 		m_logfile = m_commandline["logfile"];
 		std::cerr << "Redirecting log target to: " <<  m_logfile << std::endl;
 		if (m_logfile.size() != 0) {
-			//FIXME (very small) memory leak of 1 ofstream;
+			//TODO(unknown) (very small) memory leak of 1 ofstream;
 			//swaw the buffers (internally) of the file and wout
 			std::ofstream * widelands_out = new std::ofstream(m_logfile.c_str());
 			std::streambuf * logbuf = widelands_out->rdbuf();
@@ -1157,8 +1157,8 @@
 		 it != commandline_end;
 		 ++it)
 	{
-		//TODO: barf here on unknown option; the list of known options
-		//TODO: needs to be centralized
+		// TODO(unknown): barf here on unknown option; the list of known options
+		// needs to be centralized
 
 		g_options.pull_section("global").create_val
 			(it->first.c_str(), it->second.c_str());
@@ -170,10 +170,10 @@
 	}
 
-	//TODO: what if all the searching failed? Bail out!
+	//TODO(unknown): what if all the searching failed? Bail out!
 
 	// the directory the executable is in is the default game data directory
@@ -996,7 +996,7 @@
 	(int const argc, char const * const * const argv)
 {
-	//TODO: EXENAME gets written out on windows!
+	//TODO(unknown): EXENAME gets written out on windows!
 	m_commandline["EXENAME"] = argv[0];
 

=== modified file 'src/wui/chatoverlay.cc'